@echo off
rem This script allows to start ServletExec 2.2 for Apache for profiling with OptimizeIt.
rem IMPORTANT:
rem It must be completed before use. See the related tutorial "Profiling With ServletExec"
rem for instructions on how to complete this script (tutorials are available from Optimizeit Info/Tutorials menu)

rem Once you have fully completed the script, here are the steps you should perform to profile with OptimizeIt:
rem 1) Start the Apache server
rem 2) Execute this script to start ServletExec with the OptimizeIt's audit system
rem 3) From OptimizeIt's UI connect to the audit system (from the Program/Attach menu).

rem This should contain the path to the directory of the vm that should be used
set JAVAHOME=

rem  Specify here the path to the ServletExec directory 
set SEDIR=

rem Uncomment this line if you are using a version of ServletExec previous than ServletExec 3
rem set SEVERSION3=false
 
rem  Specify here the path to the OptimizeIt directory
set OPTITDIR=

rem  Specify here the path to the Apache document root directory
set ADOC=
rem  Specify here the full path to the Apache mime.type file
set AMIME=

rem  Increase the GCOP value if you get some "GCOP buffer too small" errors (size is in Mb)
set GCOPSIZE=1

rem  Port number used by OptimizeIt (1470 is default)
set OIPORT=1470

rem  Uncomment this line if you want to disable memory profiler
rem set OPTIONS=-dmp

rem  Uncomment this line if you use OptimizeIt's API
rem  Warning! Selecting this option will disable OptimizeIt's memory and CPU profiler
rem  Don't use that option unless you call OptimizeIt's API from your code
rem set OPTIONS=-enableAPI %OPTIONS%

rem  These are options passed to ServletExec
rem  Please refer to the ServletExec documentation for more information on these options.
set SEPORT=
set HOSTADDR=
set SENAME=
set SEOPTS=

rem Set here any extra classpath
set EXTRACP=

rem  You should not modify anything below this line
rem  --------------------------------------------------------------------------------

set JAVA=%JAVAHOME%\bin\java.exe
if exist %JAVA% goto processOptItDir
set JAVA=%JAVAHOME%\bin\jre.exe
set JAVACLASSPATH=%JAVACLASSPATH%;%JAVAHOME%\lib\rt.jar
if exist %JAVA% goto processOptItDir
echo Cannot find any java.exe or jre.exe under the directory %JAVAHOME%.
echo Please make sure to specify a correct JAVAHOME in the script startWebLogicForOptimizeIt.bat
pause
goto finish

:processOptItDir
if exist %OPTITDIR%\lib\optit.jar goto processGCOP
echo Cannot find the OptimizeIt library optit.jar under the directory %OPTITDIR%.
echo Please make sure to specify a correct OPTITDIR in the script startWebLogicForOptimizeIt.bat
pause
goto finish

:processGCOP
if not "%GCOPSIZE%"=="" set JAVAPARAMETERS=-DGCOPSIZE=%GCOPSIZE%

SET PATH=%OPTITDIR%;%PATH%
%JAVA% -classpath "%CLASSPATH%;%OPTITDIR%\lib\optit.jar" intuitive.optit.fileop.JavaTester %JAVA% 1> nul 2>&1

if "%ERRORLEVEL%"=="-1" goto vmFailed
if "%ERRORLEVEL%"=="1" goto Audit11
if "%ERRORLEVEL%"=="2" goto Audit12
if "%ERRORLEVEL%"=="3" goto AuditJNI

echo Unrecognized virtual machine. Using AuditJNI.
goto AuditJNI

:vmFailed
echo The virtual machine could not be executed correctly. Please make sure that the executable %JAVA% can be run.
goto finish

:AuditJNI
set JAVAPARAMETERS=-Xrunoii -Xms64m -Xmx64m %JAVAPARAMETERS% 
goto processClassic

:Audit12
set JAVAPARAMETERS=-Xnoclassgc -Xrunoii -Xms64m -Xmx64m -Djava.compiler=NONE %JAVAPARAMETERS% 

:processClassic
%JAVA% -classic -version 1> nul 2>&1
if not "%ERRORLEVEL%"=="0" goto noClassic
set JAVAPARAMETERS=-classic %JAVAPARAMETERS% 
goto classicDone
:noClassic
echo -classic not supported by this vm
:classicDone

set JAVACLASSPATH=.\classes\boot;%OPTITDIR%\lib\optit.jar;%JAVACLASSPATH%
goto processClassPath

:Audit11
set JAVAPARAMETERS=-ms64m -mx64m -noclassgc -Djava.compiler=NONE -DOPTITDIR=%OPTITDIR% %JAVAPARAMETERS%
set JAVACLASSPATH=%JAVAHOME%\lib\classes.zip;.\classes\boot;%OPTITDIR%\lib\optit.jar;%JAVACLASSPATH%

:processClassPath
set PATH=%OPTITDIR%\lib;%PATH%
set CLASSPATH=%JAVAHOME%\lib\classes.zip;%JAVAHOME%\lib\rt.jar;%JAVAHOME%\jre\lib\rt.jar;%SEDIR%\lib\ServletExecApache.jar;%SEDIR%\lib\servlet.jar;%SEDIR%\classes;%JAVAHOME%\lib\tools.jar;%OPTITDIR%\lib\optit.jar;%SEDIR%\..\lib\ServletExec30.jar;%SEDIR%\..\lib\servlet.jar;%EXTRACP%

if not "%SEPORT%"=="" set SEPORT=-port %SEPORT%
if not "%SENAME%"=="" set SENAME=-name %SENAME%
if not "%SEDIR%"=="" set SEDIR=-home "%SEDIR%"
if not "%AMIME%"=="" set AMIME=-mimetypes "%AMIME%"
if not "%ADOC%"=="" set ADOC=-root "%ADOC%"

set SEMAINCLASS=ServletExec
if "%SEVERSION3%"=="false" set SEMAINCLASS=ServletExecApache

rem  Run ServletExec
set CMD=%JAVA% %JAVAPARAMETERS% -classpath "%CLASSPATH%" intuitive.audit.Audit -port %OIPORT% %OPTIONS% %SEMAINCLASS% %SEPORT% %HOSTADDR% %SENAME% %SEDIR% %AMIME% %ADOC% %SEOPTS%

echo %CMD%
%CMD%

if errorlevel 1 pause

:finish








