@echo off
rem This script allows to start WebLogic 6 for profiling with OptimizeIt.
rem It should be completed before use.
rem See the tutorial 'Profiling with WebLogic 6' for more information.

rem -------------------
rem WEBLOGIC PROPERTIES
rem -------------------

rem Specify here the full path to the WebLogic install directory (ex: c:\weblogic6)
set WEBLOGIC_HOME=

rem Specify here the name of the server domain (ex: mydomain)
set DOMAIN=

rem Specify here the name of the server (ex: myserver)
set SERVER_NAME=

rem Specify here the path to your policy file (default is <WebLogicHome>\lib\weblogic.policy)
set WEBLOGIC_POLICY=.\lib\weblogic.policy

rem Optional: Specify here the server password if needed (if you do not specify it, you will be prompted for it when the server starts)
set SERVER_PASSWORD=

rem ---------------
rem JAVA PROPERTIES
rem ---------------
 
rem This should contain the path to the directory of the JVM 1.3 that should be used (ex: c:\jdk1.3)
set JAVA_HOME=

rem Comment out this line if you want to use Hotspot. 
rem IMPORTANT NOTE: you need to use the JDK 1.3.1 in order to profile with Hotspot
set CLASSIC_RUNTIME=true

rem Add extra classpath after this statement 
set CLASSPATH=

rem Add any extra java arguments after this statement
set JAVA_ARGS=-mx64M

rem ---------------------
rem OPTIMIZEIT PROPERTIES
rem ---------------------

rem This is the path to OptimizeIt directory (ex: c:\OptimizeItDemo\OptimizeIt40D)
set OPTIT_HOME=

rem Comment out this line if you want to use the OptimizeIt servlet (see the tutorial for more information)
set OPTIT_MAIN_CLASS=intuitive.audit.Audit

rem Port number used by OptimizeIt (1470 is the default)
set PORT=1470

rem Uncomment this line if you want to disable memory profiler
rem set OPTIONS="-dmp"

rem Uncomment this line if you use OptimizeIt's API
rem Warning! Selecting this option will disable OptimizeIt's memory and CPU profiler
rem Don't use that option unless you call OptimizeIt's API from your code
rem set OPTIONS="-enableAPI %OPTIONS%"

rem Increase the GCOP buffer size if you get some "GCOP buffer too small" errors during the profiling
rem (size is in Mb)
set GCOPSIZE=2

rem You should not modify anything below this line
rem  --------------------------------------------------------------------------------

set JAVA=%JAVA_HOME%\bin\java.exe
if exist %JAVA% goto processOptItDir
echo Cannot find any java.exe under the directory %JAVA_HOME%
echo Please make sure to specify a correct JAVA_HOME in the script startWebLogicForOptimizeIt.bat
pause
goto finish

:processOptItDir
if exist %OPTIT_HOME%\lib\optit.jar goto processGCOP
echo Cannot find the OptimizeIt library optit.jar under the directory %OPTIT_HOME%
echo Please make sure to specify a correct OPTIT_HOME in the script startWebLogicForOptimizeIt.bat
pause
goto finish

:processGCOP
if not "%GCOPSIZE%"=="" set JAVAPARAMETERS=-DGCOPSIZE=%GCOPSIZE%

SET PATH=%OPTIT_HOME%;%PATH%
%JAVA% -classpath "%OPTIT_HOME%\lib\optit.jar" intuitive.optit.fileop.JavaTester %JAVA% 1> nul 2>&1

if "%ERRORLEVEL%"=="-1" goto vmFailed
if "%ERRORLEVEL%"=="1" goto shouldUseJDK13
if "%ERRORLEVEL%"=="2" goto shouldUseJDK13
if "%ERRORLEVEL%"=="3" goto processClassic

echo Unrecognized virtual machine. Using AuditJNI.
goto AuditJNI

:vmFailed
echo The virtual machine could not be executed correctly. Please make sure that the executable %JAVA% can be run.
goto finish

:shouldUseJDK13
echo WebLogic 6 should be run with a JDK 1.3.
echo Make sure to set JAVA_HOME to point to a JDK 1.3 in the script startWebLogicForOptimizeIt.bat
goto finish

:processClassic
if not "%CLASSIC_RUNTIME%"=="true" goto classicDone
%JAVA% -classic -version 1> nul 2>&1
if not "%ERRORLEVEL%"=="0" goto noClassic
set JAVA_ARGS=-classic -Djava.compiler=NONE %JAVA_ARGS% 
goto classicDone
:noClassic
echo -classic not supported by this vm
:classicDone

if "%OPTIT_MAIN_CLASS%"=="" goto optionsProcessed
set OPTIT_MAIN_CLASS=%OPTIT_MAIN_CLASS% %OPTIONS% -port %PORT%
:optionsProcessed

set PREVIOUS_DIR=pwd
pushd %WEBLOGIC_HOME% 

set CLASSPATH=.;.\lib\weblogic_sp.jar;.\lib\weblogic.jar;%OPTIT_HOME%\lib\optit.jar;%CLASSPATH%
SET PATH=.\bin;%OPTIT_HOME%\lib;%PATH%

set WEBLOGIC_ARGS=""
if "%DOMAIN%"=="" goto domainDone
set WEBLOGIC_ARGS=-Dweblogic.Domain="%DOMAIN%"
:domainDone
if "%SERVER_NAME%"=="" goto serverNameDone
set WEBLOGIC_ARGS=%WEBLOGIC_ARGS% -Dweblogic.Name="%SERVER_NAME%"
:serverNameDone
if "%WEBLOGIC_HOME%"=="" goto webLogicHomeDone
set WEBLOGIC_ARGS=%WEBLOGIC_ARGS% -Dbea.home="%WEBLOGIC_HOME%"
:webLogicHomeDone
if "%WEBLOGIC_POLICY%"=="" goto policyDone
set WEBLOGIC_ARGS=%WEBLOGIC_ARGS% -Djava.security.policy=="%WEBLOGIC_POLICY%"
:policyDone
if "%SERVER_PASSWORD%"=="" goto pwDone
set WEBLOGIC_ARGS=%WEBLOGIC_ARGS% -Dweblogic.management.password="%SERVER_PASSWORD%"
:pwDone

@echo on

%JAVA% %JAVA_ARGS% -Xrunoii -classpath %CLASSPATH% %WEBLOGIC_ARGS% %OPTIT_MAIN_CLASS% weblogic.Server

@echo off

popd

if errorlevel 1 pause

:finish









