@echo off
rem This script allows to start WebLogic for profiling with OptimizeIt.
rem It should be completed before use.
rem See the tutorial 'Profiling with WebLogic' for more information.

rem This should contain the path to the directory of the vm that should be used
set JAVAHOME=

rem This is the path to OptimizeIt directory
set OPTITDIR=

rem Increase the GCOP value if you get some "GCOP buffer too small" errors
rem (size is in Mb)
set GCOPSIZE=1

rem Port number used by OptimizeIt (1470 is default)
set PORT=1470

rem Uncomment this line if you want to disable memory profiler
rem set OPTIONS="-dmp"

rem Uncomment this line if you use OptimizeIt's API
rem Warning! Selecting this option will disable OptimizeIt's memory and CPU profiler
rem Don't use that option unless you call OptimizeIt's API from your code
rem set OPTIONS="-enableAPI %OPTIONS%"

rem Add extra classpath after this statement 
set JAVACLASSPATH=

rem You should not modify anything below this line
rem  --------------------------------------------------------------------------------

set JAVA=%JAVAHOME%\bin\java.exe
if exist %JAVA% goto processOptItDir
set JAVA=%JAVAHOME%\bin\jre.exe
set JAVACLASSPATH=%JAVACLASSPATH%;%JAVAHOME%\lib\rt.jar
if exist %JAVA% goto processOptItDir
echo Cannot find any java.exe or jre.exe under the directory %JAVAHOME%.
echo Please make sure to specify a correct JAVAHOME in the script startWebLogicForOptimizeIt.bat
pause
goto finish

:processOptItDir
if exist %OPTITDIR%\lib\optit.jar goto processGCOP
echo Cannot find the OptimizeIt library optit.jar under the directory %OPTITDIR%.
echo Please make sure to specify a correct OPTITDIR in the script startWebLogicForOptimizeIt.bat
pause
goto finish

:processGCOP
if not "%GCOPSIZE%"=="" set JAVAPARAMETERS=-DGCOPSIZE=%GCOPSIZE%

SET PATH=%OPTITDIR%;%PATH%
%JAVA% -classpath "%CLASSPATH%;%OPTITDIR%\lib\optit.jar" intuitive.optit.fileop.JavaTester %JAVA% 1> nul 2>&1

if "%ERRORLEVEL%"=="-1" goto vmFailed
if "%ERRORLEVEL%"=="1" goto Audit11
if "%ERRORLEVEL%"=="2" goto Audit12
if "%ERRORLEVEL%"=="3" goto AuditJNI

echo Unrecognized virtual machine. Using AuditJNI.
goto AuditJNI

:vmFailed
echo The virtual machine could not be executed correctly. Please make sure that the executable %JAVA% can be run.
goto finish

:AuditJNI
set JAVAPARAMETERS=-Xrunoii -Xms64m -Xmx64m %JAVAPARAMETERS% 
goto processClassic

:Audit12
set JAVAPARAMETERS=-Xnoclassgc -Xrunoii -Xms64m -Xmx64m -Djava.compiler=NONE %JAVAPARAMETERS% 

:processClassic
%JAVA% -classic -version 1> nul 2>&1
if not "%ERRORLEVEL%"=="0" goto noClassic
set JAVAPARAMETERS=-classic %JAVAPARAMETERS% 
goto classicDone
:noClassic
echo -classic not supported by this vm
:classicDone

set JAVACLASSPATH=.\classes\boot;%OPTITDIR%\lib\optit.jar;%JAVACLASSPATH%
goto processClassPath

:Audit11
set JAVAPARAMETERS=-ms64m -mx64m -noclassgc -Djava.compiler=NONE -DOPTITDIR=%OPTITDIR% %JAVAPARAMETERS%
set JAVACLASSPATH=%JAVAHOME%\lib\classes.zip;.\classes\boot;%OPTITDIR%\lib\optit.jar;%JAVACLASSPATH%

:processClassPath
SET WEBLOGICCLASSPATH=.\license;.\classes;.\lib\weblogicaux.jar;.\myserver\serverclasses

SET PATH=%OPTITDIR%\lib;.\bin;%PATH%

echo "%JAVA% %JAVAPARAMETERS% -classpath %JAVACLASSPATH% -Dweblogic.class.path=%WEBLOGICCLASSPATH% -Djava.security.manager -Djava.security.policy==weblogic.policy intuitive.audit.Audit -port %PORT% %OPTIONS% weblogic.Server"

%JAVA% %JAVAPARAMETERS% -classpath %JAVACLASSPATH% -Dweblogic.class.path=%WEBLOGICCLASSPATH% -Djava.security.manager -Djava.security.policy==weblogic.policy intuitive.audit.Audit -port %PORT% %OPTIONS% weblogic.Server

if errorlevel 1 pause

:finish










